@@ -154,6 +154,8 @@ class NewtonSolverDense : public NewtonSolver {
 
     NewtonSolverDense(const NewtonSolverDense&) = delete;
 
+    NewtonSolverDense& operator=(const NewtonSolverDense& other) = delete;
+
     ~NewtonSolverDense() override;
 
     /**
@@ -212,6 +214,8 @@ class NewtonSolverSparse : public NewtonSolver {
 
     NewtonSolverSparse(const NewtonSolverSparse&) = delete;
 
+    NewtonSolverSparse& operator=(const NewtonSolverSparse& other) = delete;
+
     ~NewtonSolverSparse() override;
 
     /**
